@@ -17,7 +17,7 @@ use crate::{CreatePoolError, Manager, Pool, PoolBuilder, PoolConfig, Runtime};
 /// ```rust
 /// # use serde_1 as serde;
 /// #
-/// #[derive(serde::Deserialize)]
+/// #[derive(serde::Deserialize, serde::Serialize)]
 /// # #[serde(crate = "serde_1")]
 /// struct Config {
 ///     sqlite: deadpool_sqlite::Config,
@@ -31,7 +31,7 @@ use crate::{CreatePoolError, Manager, Pool, PoolBuilder, PoolConfig, Runtime};
 /// }
 /// ```
 #[derive(Clone, Debug, Default)]
-#[cfg_attr(feature = "serde", derive(serde_1::Deserialize))]
+#[cfg_attr(feature = "serde", derive(serde_1::Deserialize, serde_1::Serialize))]
 #[cfg_attr(feature = "serde", serde(crate = "serde_1"))]
 pub struct Config {
     /// Path to SQLite database file.
